pub struct Patch {
pub points: Box<[Point]>,
pub colors: [Rgb; 4],
}Expand description
A Coons or tensor patch: twelve or sixteen control points and four corner colours.
Fields
points: Box<[Point]>Control points, twelve for a Coons patch and sixteen for a tensor one.
colors: [Rgb; 4]The four corner colours.